/*
Copyright (C) 2004-2011 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void initSystem();
extern void drawMap(int offsetX, int offsetY);
extern void cleanup();
extern bool checkBrickContact(Entity *object);
extern void moveEntity(Entity *ent);
extern void checkObjectives(const char *name, bool alwaysInform);
extern void addTeleportParticles(float x, float y, int amount, int soundToPlay);
extern void addPlayerScore(int score);
extern void presentPlayerMedal(const char *tname);

extern Audio audio;
extern Engine engine;
extern Game game;
extern Graphics graphics;
extern Map map;

extern Entity player;
extern Entity defItem[MAX_ITEMS];
extern GameData gameData;
extern Weapon weapon[MAX_WEAPONS];
